#Purpose: similarity measures and descriptive statistics of "Zum Einfluss der ParteinÃ¤he 
#auf das Abstimmungsverhalten der Bundesverfassungsrichter
#Replicates the information that can be found in the paper on page 13
#Author: Sebastian Sternberg
#Date: 08.05.2017
#Input: adj_matrix_landau_weighted.csv
#Ouput: no output files


rm(list = ls())
#create the similarity scores per CDU/ SPD nominated judges
#Sum up the cooperation of Landau with black and red judges
df <- read.csv2("adj_matrix_landau_weighted.csv", stringsAsFactors = F)

df1 <- df[1:nrow(df),2:ncol(df)]
colours <- c("red", "black", "red", "black", "black", 
             "red", "red", "black", "red", "black", "red", "black", "black", "red", "red" )
df2 <- cbind(df1, colours)

#cooperation with Landau and the other judges
coop.landau.red <- mean(df2$Landau[which(df2$colours == "red")], na.rm = T) #62.94% with red colleagues
coop.landau.black <- mean(df2$Landau[which(df2$colours == "black")], na.rm = T) #0.74.56 % with black colleagues

#cooperation mean landau alone (0.68 %)
mean(df2$Landau)

#total average of cooperation for red and black judges
total_red <- df2[df2$colours == "red", ]
total_red <- as.matrix(total_red[, 1:15])#remove last col
total_black <- df2[df2$colours == "black", ]
total_black <- as.matrix(total_black[, 1:15]) #remove last col


total_red_score <- round(.colMeans(total_red, m= ncol(total_red), na.rm = T, n= nrow (total_red)), digits = 2)
mean(total_red_score)

total_black_score <- round(.colMeans(total_black, m= ncol(total_black), na.rm = T, n= nrow (total_black)), digits = 2)
mean(total_black_score)



#Similarity per Judge
values_per_judge <- sort(colMeans(df2[, -16], na.rm = T)) #erase last row because there are the party labels which are not numeric


#Test whether former regular judges are more similiar than others---------------------------
df4 <- df
df4$mean <- colMeans(df4[2:ncol(df4)], na.rm = T) #make the mean for each individual judge


###########################################################################
#add info about difference between former bundesrichter and politiker; just a backup test
names(df4)
df4$X

buri <- c("0", "1", "0", "0", "1", 
          "0", "1", "0", "0", "0", "1", "0", "1", "0", "1") #bundesrichter vector

poli <- c("0", "1", "0", "0", "1", 
          "0", "1", "0", "0", "2", "1", "2", "1", "0", "0" ) 

#create a new df
df5 <- cbind(df4[c(1,17)], buri, poli)
df5$buri <- as.factor(df5$buri)
df5$poli <- as.factor(df5$poli)


#ttest
t.test(mean ~ buri, data = df5) #no sign. difference betw. former regular judges and the others
#linear regression
summary(m_buri <- lm (mean ~ buri, data = df5)) #same with OLS (which actually indeed is the same)
summary(m_buri <- lm (mean ~ poli, data = df5))


#mean by former profession category
mean(df5$mean[df5$poli == "0"])
mean(df5$mean[df5$poli == "1"])
mean(df5$mean[df5$poli == "2"])

mean(df5$mean[df5$buri == "0"]) #these are the means for former non-regular judges
mean(df5$mean[df5$buri == "1"]) #these are the means for former regular judges (Berufsrichter)

#######################
#Ähnlichkeitswerte#####
#######################
#Produces all the Ähnlichkeitswerte of the communities von Figure 1 and their differences (Page13 Paper)

#mit dummies: 1 = of first (smaller) cluster, the others of the bigger cluster get a 0; 

df$dummy_2[df$X == "Di.Fabio"| df$X == "Mellinghoff" | df$X == "Landau"] <- 1
df$dummy_2[df$X == "Broß"| df$X == "Lübbe.Wolff" | df$X == "Gerhardt" | df$X == "Voßkuhle"| df$X == "Osterloh"] <- 0

#calculate the means for the two groups
broß <- mean(df$Broß[df$dummy_2== 0], na.rm = T) #wie nahe ist bross on average mit den anderen mitgliedern in dem cluster (df$dummy == 0?)
gerhardt <- mean(df$Gerhardt[df$dummy_2== 0], na.rm = T)
voßkuhle <- mean(df$Voßkuhle[df$dummy_2== 0], na.rm = T)
luebbe <- mean(df$Lübbe.Wolff[df$dummy_2== 0], na.rm = T)
osterloh <- mean(df$Osterloh[df$dummy_2== 0], na.rm = T)

#for the three in the smaller cluster
difabio <- mean(df$Di.Fabio[df$dummy_2== 1], na.rm = T)
mellinghof <- mean(df$Mellinghoff[df$dummy_2== 1], na.rm = T)
landau <- mean(df$Landau[df$dummy_2== 1], na.rm = T)

#as yoiu can see, those values are all high; this is exactly what the cluster algorithm does: cluster those which 
#are similiar

#Cluster 1 mean:
c1_mean <- (difabio + mellinghof + landau)/ 3

#Cluster 2 mean 
c2_mean <- (broß + gerhardt + voßkuhle + luebbe+ osterloh)/ 5


#these high values show that the groups are internally pretty similar/ Ã¤hnlich; 
#next step is to show that they differ greatly between the two clusters

#difference between the groups: 
difa_dif <- mean(df$Di.Fabio[df$dummy_2== 0], na.rm = T) #give me the mean of difabio's cooperation with judges from the other cluster
melli_dif <- mean(df$Mellinghoff[df$dummy_2== 0], na.rm = T)
landau_dif <- mean(df$Landau[df$dummy_2== 0], na.rm = T)

#those values are way smaller than in the cluster itself; this is what we want to see

#mean difference between the three in the smaller cluster with the rest
cluster.dif <- (difa_dif + melli_dif + landau_dif) / 3 #0.46

#final step is to calculate the difference between the greater cluster, and the judges in the smaller cluster to those in the greater
c2_mean - cluster.dif #0.30


#get the mean for the one big cluster in the second community plot; the group consists of Huber, LÃ¼bbe, MÃ¼ller,
#Landau, Kessal, Hermanns, Voßkuhle, Gerhardt

cluster2_mean <- mean(colMeans(df[, 7:14], na.rm = T)) # gives the mean of the colmeans; colmeans = Ãhnlichkeitswert of certain judge



