#Purpose: Automated creation of adj. matrix of BVerfG Network in the period of Landau
#Author: Sebastian Sternberg
#Date: 22.11.2016
#Input: sondervoten_landau.csv
#Output: adj_matrix_landau_weighted.csv, adj_matrix_landau_weighted_reduced.csv
rm(list = ls())
require(Matrix)

#set wd

#read the original data set
df.orig <- read.csv2("landau_sondervoten_aktualisiert.csv", encoding = "UTF-8")

df <- df.orig[, 8:ncol(df.orig)] #drop the unnecessary cols of the original data set

#recode  1 and na to zero, and 2 as a 1, as we want to find the instances where judges wrote a sep. op. together
#this is because in the original matrix, judges who wrote an opinion together are coded with a 2, 
#and judges who are coded with a 1.

df[df == 1] <- 0
df[df == 2] <- 1
df[is.na(df)] <- 0

#make the crossproduct of the transpose to find the instances where they worked together, write a sondervotum together
df1 <- tcrossprod(t(as.matrix(df))) #note that cooperation with themselves (=1) are not real cooperations; this is why they are not taken into account for the cooperation score; 
#also, this is why the diag does not sum up to 15/ 100% respectively

#find the instances where the judges in the majority cooperated; writing NOT a sep. opinion counts as cooperation
df <- df.orig[, 8:ncol(df.orig)]

#recode again
df[df > 0] <- -1
df[df == 0] <- 1
df[df == -1 |is.na(df)] <- 0 

#again do the crossproduct of the transpose so that we find the instances where they collaborated in the maj.; write nota sondervotum together
df2 <- tcrossprod(t(as.matrix(df)))


# df <- df.orig[, 9:ncol(df.orig)]
# df[df != 1] <- 0
# 
# df[is.na(df)] <- 0
# 
# colSums(df) #jeder wieoft alleine

#create the final matrix by simply adding the two matrices up; the final matrix contains the information of how often a judge cooperates with another judge
df.final <- df1 + df2
df.final <- as.matrix(df.final)

#create a weighted matrix where we weight it according to the realised amount of coopreations 
#relative to the possible amount of cooperation

#first create a matrix that counts how often judges participated overall
df.weighting  <- df.orig[, 8:ncol(df.orig)]
df.weighting[!is.na(df.weighting)] <- 1
df.weighting[is.na(df.weighting)] <- 0

#count how often they participated with one another
df.weighting <- tcrossprod(t(as.matrix(df.weighting)))

#weight it
df.final.weighting <- df.final / df.weighting


#save it as csv
diag(df.final.weighting) <- 1
write.csv2(df.final.weighting, file = "adj_matrix_landau_weighted.csv")








########################################################################################
#make the new matrix with a drop of 6 decisions----------------------------------------#
########################################################################################
df.orig1 <- read.csv2("landau_sondervoten_aktualisiert.csv")

#delete all the rows that are 
df.orig1 <- df.orig1[ ! df.orig1$Kennung %in% c("2 BvL 11/04", 
                                            "2 BvF 3/02", 
                                            "2 BvR 2661/06 ", 
                                            "2 BvC 4/10, 2 BvC 6/10, 2 BvC 8/10", 
                                            "2 BvR 2302/11", 
                                            "2 BvE 2/13,  2 BvR 2220/13"), ] #drop all the rows with these aktenzeichen


df.orig1 <- df.orig1[, 8:ncol(df.orig1)] #drop the id variables to obtain a clean data set

#start creating the first matrix with the cooperation in sondervoten
df <- df.orig1

df[df == 1] <- 0
df[df == 2] <- 1
df[is.na(df)] <- 0

df1_reduced <- tcrossprod(t(as.matrix(df)))

#second matrix
df <- df.orig1

df[df > 0] <- -1
df[df == 0] <- 1
df[df == -1 |is.na(df)] <- 0

df2_reduced <- tcrossprod(t(as.matrix(df)))


# df <- df.orig1
# df[df != 1] <- 0
# 
# df[is.na(df)] <- 0
# 
# colSums(df) #jeder wieoft alleine
# 
df.final1 <- df1_reduced + df2_reduced
df.final1 <- as.matrix(df.final1)


#weight it

df.weighting1  <- df.orig1

df.weighting1[!is.na(df.weighting1)] <- 1
df.weighting1[is.na(df.weighting1)] <- 0

df.weighting1 <- tcrossprod(t(as.matrix(df.weighting1)))

df.final.weighting1 <- df.final1 / df.weighting1

#save it
diag(df.final.weighting1) <- 1
write.csv2(df.final.weighting1, file = "adj_matrix_landau_weighted_reduced.csv")
