* ***************************************************************** *
* ***************************************************************** *
*   File-Name:      mds_reduced.do                                  *
*   Date:           Dez 11, 2016                                    *
*   Author:         TG                                              *
*   Purpose:      	Robustheitstests - Analysis of similarity data  *
*  					Sondervoten Landau						        *
*   Input File:     Values of adj_matrix_landau_weighted_reduced.csv*
*   Output File:    Äquivalente Versionen von Abbildung 2 & 3       *
* ****************************************************************  *
* ****************************************************************  *

* minor fixes to correct data errors in input matrix, Dezember 11, 2016




* *************************************************************************
* Robustheitstest mit N= 14 Fällen, wie im paper beschrieben:             *
*																		  *
* "Dies gilt auch dann, wenn man die problematischen sechs Entscheidungen *
* (Nr. 2, 6, 10, 11, 15 und 17 in Tabelle 1) herausrechnet. Im Vergleich  *
* der beiden Berechnungen ergeben sich Unterschiede lediglich im Detail   *
* bezüglich der Ähnlichkeitswerte, was aber die Resultate der             *
* multidimensionalen Skalierung nicht entscheidend verändert."            *
***************************************************************************



version 14.2
clear
capture log close
set more off

*************************
** Get similarity data **
*************************

* Define Names of judges for 1st period
global names Bross	Osterloh	DiFabio	Mellinghoff	Lübbe-Wolff	Gerhardt	Landau	Voßkuhle 
 
*values  of the matrix below are based on adj_matrix_landau_weighted_reduced.csv 
matrix input Landau1_red = ( ///
0.857142857142857	0.285714285714286	0.428571428571429	0.714285714285714	0.857142857142857	0.428571428571429	0 ///
	0.428571428571429	0.285714285714286	0.571428571428571	0.857142857142857	0.285714285714286	1 ///
		0.857142857142857	0.375	0.25	0.75	1 ///
			0.428571428571429	0.285714285714286	0.857142857142857	0 ///
				0.454545454545455	0.363636363636364	0.4 ///
					0.272727272727273	0.4 ///
						0.571428571428571)



* Higher values for protect() will show that we actually reached a global minimum!
mdsmat Landau1_red, names($names) shape(uupper) s2d(oneminus) meth(modern) init(random(12345)) protect(10) nolog config

* Check diagnostics
estat quantiles
estat correlations
estat pairwise



*************************
** Graph Configuration **
*************************


* Save coordinates into data set
predict d1 d2, config saving(Landau1_red, replace)

use Landau1_red, clear


* Deviations indicate lack of fit when regressing (transformed) disimilarities on distance	
* looks reasonable, but more off than with full data set										
mdsshepard									
mdsshepard, separat		


replace Category="Broß" if Category=="Bross"
replace Category="Di Fabio" if Category=="DiFabio"

set obs 8
capture drop pos spd
generate pos = 3
replace pos=9 if Category=="Lübbe-Wolff"
replace pos=9 if Category=="Voßkuhle"
replace pos=9 if Category=="Osterloh"
replace pos=9 if Category=="Gerhardt"

gen spd= (inlist(Category, "Osterloh", "Lübbe-Wolff", "Gerhardt","Voßkuhle"))


ren d2 dim2
gen d2 = -1*dim2 /* MDS is invariant to orthogonal rotation */


ren d1 dim1
gen d1 = -1*dim1 /* MDS is invariant to orthogonal rotation */


#delimit;
twoway scatter  d2 d2 if spd==1,  mlabvpos(pos) 
mcolor(gray) mlabel(Category) mlabcolor(gray) msymbol(Oh)||
 scatter  d2 d1 if spd==0,  mlabvpos(pos) 
mcolor(black) mlabel(Category) mlabcolor(black) msymbol(O)
scheme(s1mono)                                 
    legend(off)                                                                          
    ylabel(-.5(.1).5,  nolabel )    xsize(2.4)
	xlabel(-.5(.1).5,  nolabel )    ysize(2)
	xscale(titlegap(3) nofextend ) 
	yscale(titlegap(3) nofextend )
	xtitle(" ")
	ytitle(" ")        
	graphregion(fcolor(white)) 
	plotregion(lcolor(white))
saving(landau1_red,replace);
#delimit cr;


*Produces equivqlent to Figure 2 in the Paper
graph export landau1_red.pdf, replace
graph export landau1_red.tif, replace
graph export landau1_red.pdf, replace
graph export landau1_red.png, replace





*************************
** Get similarity data **
*************************

* Define Names of judges for 2nd period
global names2 Lübbe-Wolff	Gerhardt	Landau	Voßkuhle	Huber	Hermanns Müller	Kessal-Wulf 


*values  of the matrix below are based on adj_matrix_landau_weighted_reduced.csv 

matrix input Landau2_red = ( ///
0.454545454545455	0.363636363636364	0.4	0.5	0.5	0.333333333333333	0 ///
	0.272727272727273	0.4	0.5	0.5	0.666666666666667	0 ///
		0.571428571428571	0.714285714285714	0.714285714285714	0.666666666666667	1 ///
			0.833333333333333	1	1	0.5 ///
				0.714285714285714	0.666666666666667	0.6 ///
					1	0.6 ///
						0.6)

* Higher values for protect() will show that we actually reached a global minimum!
mdsmat Landau2_red, names($names2) shape(uupper) s2d(oneminus) meth(modern) init(random(12345)) protect(10) nolog config


* Check diagnostics
estat quantiles
estat correlations
estat pairwise



*************************
** Graph Configuration **
*************************


* Save coordinates into data set
predict d1 d2, config saving(Landau2_red, replace)

use Landau2_red, clear

* Deviations indicate lack of fit when regressing (transformed) disimilarities on distance	
* looks resonable										
mdsshepard									
mdsshepard, separat		


set obs 8
capture drop pos2 
generate pos2 = 3
replace pos2 = 6 if Category=="Hermanns"
replace pos2 = 10 if Category=="Voßkuhle"
replace pos2 = 10 if Category=="Kessal-Wulf"


ren d1 dim1
ren d2 dim2

gen d1 = -1*dim1 /* MDS is invariant to orthogonal rotation */
gen d2 = -1*dim2 /* MDS is invariant to orthogonal rotation */


gen spd= (inlist(Category, "Hermanns", "Lübbe-Wolff", "Gerhardt",	"Voßkuhle"))

#delimit;
twoway scatter  d2 d1 if spd==1,  mlabvpos(pos2) 
mcolor(gray) mlabel(Category) mlabcolor(gray) msymbol(Oh) ||
 scatter  d2 d1 if spd==0,  mlabvpos(pos2) 
mcolor(black) mlabel(Category) mlabcolor(black) msymbol(O)
scheme(s1mono)                                 
    legend(off)                                                                          
    ylabel(-.5(.1).5,  nolabel )    
	xlabel(-.5(.1).5,  nolabel )
	xscale(titlegap(3) nofextend ) xsize(2.4)
	yscale(titlegap(3) nofextend ) ysize(2)
	xtitle(" ")
	ytitle(" ")        
	graphregion(fcolor(white)) 
	plotregion(lcolor(white))
saving(landau2_red,replace);
#delimit cr;

*Produces equivalent to Figure 3 in the Paper for reduced data set
graph export landau2_red.pdf, replace
graph export landau2_red.tif, replace
graph export landau2_red.pdf, replace
graph export landau2_red.png, replace

									

